@@ -4,8 +4,8 @@ from aws_lambda_powertools.utilities.data_classes import (
 )
 
 
-from cdev.resources.simple.api import Api
-from cdev.resources.simple.xlambda import simple_function_annotation
+from cdev.aws.api import Api
+from cdev.aws.lambda_function import ServerlessFunction
 
 from cdev import Project as cdev_project
 
@@ -16,7 +16,11 @@ DemoApi = Api("demoapi")
 hello_route = DemoApi.route("/helloworld", "GET")
 
 
-@simple_function_annotation("dataclass_example", events=[hello_route.event()], tags={"environment": "dev", "sample_tag": "handler"})
+@ServerlessFunction(
+    "dataclass_example",
+    events=[hello_route.event()],
+    tags={"environment": "dev", "sample_tag": "handler"},
+)
 @event_source(data_class=APIGatewayProxyEventV2)
 def lambda_handler(event: APIGatewayProxyEventV2, context):
     if "helloworld" in event.path and event.http_method == "GET":
