@@ -1,6 +1,6 @@
 from aws_lambda_powertools import Tracer
 
-from cdev.resources.simple.xlambda import simple_function_annotation
+from cdev.aws.lambda_function import ServerlessFunction
 
 from src.examples.config import powertool_vars, tracer_permissions
 
@@ -12,7 +12,7 @@ def collect_payment(charge_id: str):
     print(f"Collected charge: {charge_id}")
 
 
-@simple_function_annotation(
+@ServerlessFunction(
     "tracer_example", environment=powertool_vars, permissions=[tracer_permissions]
 )
 @tracer.capture_lambda_handler
