@@ -9,16 +9,17 @@ from typing import List
 
 from sortedcontainers import SortedList
 
-INCLUDE_REGEX = '^#include <(\w+)>$'
+INCLUDE_REGEX = "^#include <(\w+)>$"
+
 
 def _hash_line_numbers(line_no_1: int, line_no_2: int) -> str:
     s_numbers = f"{line_no_1}:{line_no_2}"
-    return int.from_bytes( hashlib.md5(s_numbers.encode()).digest(), byteorder='big')
+    return int.from_bytes(hashlib.md5(s_numbers.encode()).digest(), byteorder="big")
 
 
-class parsed_function():
+class parsed_function:
     """
-        This class represents the information for a parsed function. It mostly is used to house a function that can keep track of the line numbers.
+    This class represents the information for a parsed function. It mostly is used to house a function that can keep track of the line numbers.
     """
 
     def __init__(self, name):
@@ -28,32 +29,36 @@ class parsed_function():
         # set of imported packages
         self.imported_packages: str = set()
 
-        # some packages come with the lambda runtime so they do not need to be packaged into a layer so we need to make a new set with 
+        # some packages come with the lambda runtime so they do not need to be packaged into a layer so we need to make a new set with
         # just packages we need to actually package into layers
         # EX: 'os' does not need to be packaged into a layer
         self.needed_imports = set()
 
         self.needed_imports_hash = ""
 
-    def __eq__(self):
+    def __eq__(self) -> bool:
         return self.name == self.name
 
-    def add_line_numbers(self, line_no):
+    def add_line_numbers(self, line_no) -> None:
         # Use a sorted list
         self.needed_line_numbers.add(line_no)
 
-    def get_line_numbers(self):
+    def get_line_numbers(self) -> SortedList:
         return self.needed_line_numbers
 
-    def get_line_numbers_serializeable(self):
+    def get_line_numbers_serializeable(self) -> List:
         return list(self.needed_line_numbers)
 
-    def add_import(self, global_import_obj):
-        #self.add_line_numbers(global_import_obj.get_line_no())
+    def add_import(self, global_import_obj) -> None:
+        # self.add_line_numbers(global_import_obj.get_line_no())
         # original package will be how it is denoted in the import statement
         # for absolute packages we only want the top level name (absolutes don't start with '.')
         # for relative packages we want the entire name (relatives start with '.')
-        top_level_package_name = global_import_obj.original_package.split('.')[0] if not global_import_obj.original_package.startswith('.') else global_import_obj.original_package
+        top_level_package_name = (
+            global_import_obj.original_package.split(".")[0]
+            if not global_import_obj.original_package.startswith(".")
+            else global_import_obj.original_package
+        )
         self.imported_packages.add(top_level_package_name)
 
 
@@ -64,12 +69,13 @@ class GlobalStatementType(Enum):
     CLASS_DEF = 4
 
 
-class GlobalStatement():
+class GlobalStatement:
     """
-        This class represents the extra information for the global statements of a file. A global statement are the first children in the 
-        ast for a file. 
+    This class represents the extra information for the global statements of a file. A global statement are the first children in the
+    ast for a file.
     """
-    def __init__(self, node, line_no, symbols):
+
+    def __init__(self, node, line_no, symbols) -> None:
         self.line_no = line_no
 
         self.set_symbols(symbols)
@@ -81,17 +87,16 @@ class GlobalStatement():
         # The type of statement
         self.statement_type = GlobalStatementType.STANDARD
 
-
     def __hash__(self):
         return self.hashed
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         return self.hashed == other.hashed
 
     def __repr__(self):
         return f"<statement at {self.line_no[0]} thru {self.line_no[1]}>"
 
-    def set_symbols(self, symbols: List[str]):
+    def set_symbols(self, symbols: List[str]) -> None:
         self.symbols = symbols
 
     def get_symbols(self) -> List[str]:
@@ -128,11 +133,11 @@ class ImportStatement(GlobalStatement):
 class FunctionStatement(GlobalStatement):
 
     # function name is a func
-    func_name = ""
+    func_name: str = ""
 
-    has_decremented = False
+    has_decremented: bool = False
 
-    def __init__(self, node, line_no, symbol_table, name):
+    def __init__(self, node, line_no, symbol_table, name) -> None:
         super().__init__(node, line_no, symbol_table)
         self.func_name = name
         self.has_decremented = False
@@ -140,21 +145,19 @@ class FunctionStatement(GlobalStatement):
     def get_type(self):
         return GlobalStatementType.FUNCTION
 
-    def get_function_name(self):
+    def get_function_name(self) -> str:
         return self.func_name
 
-    def decrement_line_number(self):
+    def decrement_line_number(self) -> None:
         if self.has_decremented:
             return
-        
-        
+
         old_lineno = self.line_no
-        self.line_no = [old_lineno[0]+1, old_lineno[1]]
+        self.line_no = [old_lineno[0] + 1, old_lineno[1]]
         self.has_decremented = True
 
 
 class ClassDefinitionStatement(GlobalStatement):
-
     def __init__(self, node, line_no, symbol_table, name):
         super().__init__(node, line_no, symbol_table)
         self.class_name = name
@@ -162,23 +165,22 @@ class ClassDefinitionStatement(GlobalStatement):
     def get_type(self):
         return GlobalStatementType.CLASS_DEF
 
-    def get_class_name(self):
+    def get_class_name(self) -> str:
         return self.class_name
-    
 
 
-
-class file_information():
+class file_information:
     """
-        This class represents a file that needs to have functions parsed out of it. 
+    This class represents a file that needs to have functions parsed out of it.
     """
 
     # init method or constructor
-    def __init__(self, location):
+    def __init__(self, location) -> None:
         if not os.path.isfile(location):
             raise FileNotFoundError(
-                f"parser_utils: could not find file at -> {location}")
-        
+                f"parser_utils: could not find file at -> {location}"
+            )
+
         # Path to the file
         self.file_location = location
 
@@ -197,7 +199,6 @@ class file_information():
         # dict<str, global_statement>: function name to its global statement
         self.global_functions = {}
 
-        
         # dict<statement, list(str)>: function from statement to symbols
         self.statement_to_symbol = {}
 
@@ -216,23 +217,23 @@ class file_information():
         # symbol table for the file
         self.symbol_table = None
 
-        
         # abstract syntax tree for the file
         self.ast = ""
 
-        with open(location, 'r') as fh:
+        with open(location, "r") as fh:
             self.src_code = fh.readlines()
             fh.seek(0)
 
             for toktype, tok, start, end, line in tokenize.generate_tokens(fh.readline):
                 # we can also use token.tok_name[toktype] instead of 'COMMENT'
-                # from the token module 
+                # from the token module
                 if toktype == tokenize.COMMENT:
                     self._evaluate_comment(line, start)
 
         try:
-            self.symbol_table = symtable.symtable("".join(self.src_code),
-                                                  location, 'exec')
+            self.symbol_table = symtable.symtable(
+                "".join(self.src_code), location, "exec"
+            )
         except SyntaxError as e:
             print(e)
 
@@ -242,7 +243,7 @@ class file_information():
             print(e)
 
     def _evaluate_comment(self, line, start):
-        #print(f"COMMENT {start} {line}")
+        # print(f"COMMENT {start} {line}")
 
         match_obj = re.match(INCLUDE_REGEX, line)
 
@@ -250,12 +251,11 @@ class file_information():
             if len(match_obj.groups()) == 1:
                 self.include_overrides_lineno[match_obj.groups()[0]] = start[0]
 
-
-    def get_source_code(self):
+    def get_source_code(self) -> str:
         return "".join(self.src_code)
 
-    def get_lines_of_source_code(self, start_line, end_line):
-        return "".join(self.src_code[(start_line - 1):(end_line)])
+    def get_lines_of_source_code(self, start_line, end_line) -> str:
+        return "".join(self.src_code[(start_line - 1) : (end_line)])
 
     def get_symbol_table(self):
         return self.symbol_table
@@ -263,32 +263,31 @@ class file_information():
     def get_ast(self):
         return self.ast
 
-    def add_global_statement(self, global_statement):
+    def add_global_statement(self, global_statement) -> None:
         self.top_level_statements.append(global_statement)
         self.statement_to_symbol[global_statement] = set()
 
     def get_global_statements(self) -> List[GlobalStatement]:
         return self.top_level_statements
 
-    def get_file_length(self):
+    def get_file_length(self) -> int:
         return len(self.src_code)
 
-    def add_global_function(self, name, global_obj):
+    def add_global_function(self, name, global_obj) -> None:
         self.global_functions[name] = global_obj
         self.add_global_statement(global_obj)
 
-    def add_global_import(self, global_obj):
-        self.imported_symbol_to_global_statement[
-            global_obj.as_symbol] = global_obj
-            
+    def add_global_import(self, global_obj) -> None:
+        self.imported_symbol_to_global_statement[global_obj.as_symbol] = global_obj
+
         self.add_global_statement(global_obj)
 
-    def add_class_definition(self, name, global_obj):
+    def add_class_definition(self, name, global_obj) -> None:
         self.global_functions[name] = global_obj
         self.add_global_statement(global_obj)
 
-    def add_parsed_functions(self, func):
+    def add_parsed_functions(self, func) -> None:
         self.parsed_functions.append(func)
 
-    def set_imported_symbols(self, symbols):
+    def set_imported_symbols(self, symbols) -> None:
         self.imported_symbols = symbols
